@@ -4,7 +4,7 @@ use strict;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw/to_singular is_plural/;
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 # Irregular plurals.
 
@@ -53,6 +53,253 @@ my %irregular = (qw/
     theses thesis
     those that
     women woman
+ad-men ad-man
+admen adman
+aircraftmen aircraftman
+airmen airman
+airwomen airwoman
+alaskamen alaskaman
+aldermen alderman
+anchormen anchorman
+ape-men ape-man
+assemblymen assemblyman
+backwoodsmen backwoodsman
+bandsmen bandsman
+barmen barman
+barrow-men barrow-man
+batmen batman
+batsmen batsman
+beggarmen beggarman
+beggarwomen beggarwoman
+behmen behman
+boatmen boatman
+bogeymen bogeyman
+bowmen bowman
+brakemen brakeman
+bushmen bushman
+businessmen businessman
+businesswomen businesswoman
+busmen busman
+byre-men byre-man
+cabmen cabman
+cameramen cameraman
+carmen carman
+cattlemen cattleman
+cavalrymen cavalryman
+cavemen caveman
+chairmen chairman
+chairwomen chairwoman
+chapmen chapman
+charwomen charwoman
+chessmen chessman
+chinamen chinaman
+churchmen churchman
+clansmen clansman
+classmen classman
+clemen cleman
+clergymen clergyman
+coachmen coachman
+coalmen coalman
+cognomen cognoman
+con-men con-man
+congressmen congressman
+congresswomen congresswoman
+councilmen councilman
+councilwomen councilwoman
+countrymen countryman
+countrywomen countrywoman
+cowmen cowman
+cracksmen cracksman
+craftsmen craftsman
+cragsmen cragsman
+crewmen crewman
+cyclamen cyclaman
+dairymen dairyman
+dalesmen dalesman
+doormen doorman
+draftsmen draftsman
+draughtsmen draughtsman
+dustmen dustman
+dutchmen dutchman
+englishmen englishman
+englishwomen englishwoman
+ex-servicemen ex-serviceman
+excisemen exciseman
+fellow-men fellow-man
+ferrymen ferryman
+fieldsmen fieldsman
+firemen fireman
+fishermen fisherman
+flagmen flagman
+footmen footman
+foremen foreman
+forewomen forewoman
+freedmen freedman
+freemen freeman
+frenchmen frenchman
+frenchwomen frenchwoman
+freshmen freshman
+frogmen frogman
+frontiersmen frontiersman
+g-men g-man
+gentlemen gentleman
+gentlewomen gentlewoman
+germen german
+god-men god-man
+gombeen-men gombeen-man
+groundsmen groundsman
+guardsmen guardsman
+gunmen gunman
+handymen handyman
+hangmen hangman
+harmen harman
+he-men he-man
+headmen headman
+helmsmen helmsman
+hemmen hemman
+henchmen henchman
+herdsmen herdsman
+highwaymen highwayman
+horsemen horseman
+horsewomen horsewoman
+housemen houseman
+huntsmen huntsman
+husbandmen husbandman
+hymen hyman
+icemen iceman
+indiamen indiaman
+infantrymen infantryman
+irishmen irishman
+irishwomen irishwoman
+jazzmen jazzman
+journeymen journeyman
+jurymen juryman
+kinmen kinman
+kinsmen kinsman
+kinswomen kinswoman
+klansmen klansman
+landsmen landsman
+laundrymen laundryman
+laundrywomen laundrywoman
+lawmen lawman
+laymen layman
+liegemen liegeman
+liftmen liftman
+linemen lineman
+linesmen linesman
+linkmen linkman
+liverymen liveryman
+lobstermen lobsterman
+longshoremen longshoreman
+lumbermen lumberman
+madmen madman
+madwomen madwoman
+mailmen mailman
+marksmen marksman
+medicine-men medicine-man
+men man
+merchantmen merchantman
+mermen merman
+middlemen middleman
+midshipmen midshipman
+militiamen militiaman
+milkmen milkman
+minutemen minuteman
+motormen motorman
+muffin-men muffin-man
+musclemen muscleman
+needlewomen needlewoman
+newsmen newsman
+newspapermen newspaperman
+newswomen newswoman
+night-watchmen night-watchman
+noblemen nobleman
+nomen noman
+norsemen norseman
+northmen northman
+nurserymen nurseryman
+oarsmen oarsman
+oarswomen oarswoman
+oehmen oehman
+oilmen oilman
+ombudsmen ombudsman
+orangemen orangeman
+pantrymen pantryman
+patrolmen patrolman
+pitchmen pitchman
+pitmen pitman
+placemen placeman
+plainsmen plainsman
+ploughmen ploughman
+pointsmen pointsman
+policemen policeman
+policewomen policewoman
+postmen postman
+potmen potman
+pressmen pressman
+property-men property-man
+quarrymen quarryman
+raftsmen raftsman
+ragmen ragman
+railwaymen railwayman
+repairmen repairman
+riflemen rifleman
+roadmen roadman
+roundsmen roundsman
+salarymen salaryman
+salesmen salesman
+saleswomen saleswoman
+salmen salman
+sandwichmen sandwichman
+schoolmen schoolman
+scotchmen scotchman
+scotchwomen scotchwoman
+scotsmen scotsman
+scotswomen scotswoman
+seamen seaman
+seedsmen seedsman
+servicemen serviceman
+showmen showman
+sidesmen sidesman
+signalmen signalman
+snowmen snowman
+specimen speciman
+spokesmen spokesman
+spokeswomen spokeswoman
+sportsmen sportsman
+stablemen stableman
+stamen staman
+stammen stamman
+statesmen statesman
+steersmen steersman
+supermen superman
+superwomen superwoman
+switchmen switchman
+swordsmen swordsman
+t-men t-man
+tallymen tallyman
+taxmen taxman
+townsmen townsman
+tradesmen tradesman
+trainmen trainman
+trenchermen trencherman
+tribesmen tribesman
+turkmen turkman
+tutankhamen tutankhaman
+underclassmen underclassman
+vestrymen vestryman
+vonallmen vonallman
+washerwomen washerwoman
+watchmen watchman
+watermen waterman
+weathermen weatherman
+welshmen welshman
+women woman
+woodmen woodman
+woodsmen woodsman
+workmen workman
+yachtsmen yachtsman
+yeomen yeoman
 /);
 
 # Words ending in ves need care, since the ves may become "f" or "fe".
